*********************************************
* Ford Education Paper
* JLMPS 2016 (and sometimes PAPFAM 2009)
* Descriptive Graphs (and Tables) 
* v23
* 2021.11.18
*********************************************

clear
set scheme s1mono


***********
*Retro validation
***********

use "Data/JLMPS 2016 xs v1.1.dta", clear

*Age in September of interview year
gen dec_age=floor((2016-brthyr)+(12-brthm)/12)

*Analysis sample
*December ages 6-24
keep if dec_age>=6 & dec_age<=24

*Jordanians 
keep if nationality_cl==1

*Ever went to school
keep if q3001==2 | q3001==3

*Predict with years for basic
gen pred_start=6+brthyr

*Start is same
count if pred_start==q2121 & pred_start!=. & q2121!=.
*Start is different
count if pred_start!=q2121 & pred_start!=. & q2121!=.

count if (pred_start==q2121) | (pred_start==q2121+1) & pred_start!=. & q2121!=.
count if pred_start!=. & q2121!=.

***********
*Additional summary statistics
***********

*Table 2 appendix
use "Data/Syrians pre and post crisis- educ.dta", clear

gen count=1
*Analysis sample
*December ages 6-24
keep if dec_age>=6 & dec_age<=24

collapse (sum) count, by(dec_age group)
drop if group==.

reshape wide count, i(dec_age) j(group)

rename count1 Jordanians_2016
rename count2 Syrians_2016
rename count3 Syrians_2009 

export excel using "Graphs and Tables/syrians and jordanians by age", firstrow(variables) replace 


*Table 3 appendix
use "Data/Syrians pre and post crisis- educ.dta", clear

*Analysis sample
*December ages 6-24
keep if dec_age>=6 & dec_age<=24
*Syrians in 2016
keep if group==2

tabout sex motheredcat fatheredcat older_brothers older_sisters younger_brothers younger_sisters [aw=expan_indiv] using "Graphs and Tables/Desc statistics.xls", cells(col) ptotal(single) npos(col) format(1) show(all) oneway replace

tabout group using "Graphs and Tables/Desc statistics.xls", cells(mean nsibs) format(1) show(all) append sum





***********
*Stat: Footnote: Child and Youth Labor
***********

use "Data/Syrians pre and post crisis- educ.dta", clear

keep if nationality==405

*Employment
table sex if age>=15 & age<=19 [pw=expan_indiv], c(mean usemp1)
*6%
table sex if age>=20 & age<=24 [pw=expan_indiv], c(mean usemp1)
*33%

**************
* Figure 1: Enrollment with CI and stats
**************

*Syrians
use "Data/Syrians pre and post crisis- educ.dta", clear

*Ages 6-22 in December
keep if dec_age>=6 & dec_age<=22
keep if student!=.

*Triply interacted model for sex, age in Dec., group
logit student b1.sex##b6.dec_age##b1.group ///
, ///
cluster(psu) or

*Predicted probabilites
margins, over(sex dec_age group) predict(pr) post

*Graphing predicted probabilies
mplotoffset, plotd(group) by(sex) byopts(row(3) title("") yrescale xrescale) plotregion(margin(l=5 r=5 b=0 t=0)) ///
xtitle("Age") ytitle("Probability enrolled") ///
plot1opts(lcolor(gs7) lpatt(dash) mcolor(gs7))  ///
plot2opts(lcolor(gs1) lpatt("l") mcolor(gs1))  ///
ci1opts(lcolor(gs7) lpatt(dash) msize(4))  ///
ci2opts(lcolor(gs1) lpatt("l") msize(4))  ///
ylabel(0(.2)1.1) ytick(0(.2)1.1) xlabel() xtick() ///
title(" ") offset(0.05) ysize(20) xsize(12) legend(size(3))

graph save "Graphs and Tables/enroll_sex_age.gph", replace
graph export "Graphs and Tables/enroll_sex_age.png", replace

*Test within sex and year of age across groups (comparing Jordanians, PAPFAM to Syrians in Jordan)
foreach num_g of numlist 1 3 {
foreach num_s of numlist 1/2 {
foreach num_a of numlist 6/22 {

test _b[`num_s'.sex#`num_a'.dec_age#`num_g'.group]=_b[`num_s'.sex#`num_a'.dec_age#2.group]
}
}
}

*Test within age and group and across sex for Syrians
foreach num_a of numlist 6/22 {

test _b[1.sex#`num_a'.dec_age#2.group]=_b[2.sex#`num_a'.dec_age#2.group]
}


*Syrians only
use "Data/Syrians pre and post crisis- educ.dta", clear

*Same 6-22 
keep if dec_age>=6 & dec_age<=22
keep if expan_indiv!=.
*Syrians
keep if group==2
fre group

*Model
logit student b1.sex##b6.dec_age ///
, ///
cluster(psu) or

*Test of interactions with sex
test 2.sex#6bn.dec_age ///
2.sex#7.dec_age ///
2.sex#8.dec_age ///
2.sex#9.dec_age ///
2.sex#10.dec_age ///
2.sex#11.dec_age ///
2.sex#12.dec_age ///
2.sex#13.dec_age ///
2.sex#14.dec_age ///
2.sex#15.dec_age ///
2.sex#16.dec_age ///
2.sex#17.dec_age ///
2.sex#18.dec_age ///
2.sex#19.dec_age ///
2.sex#20.dec_age ///
2.sex#21.dec_age ///
2.sex#22.dec_age
*Joint sig.


*********************************
*NERs
********************************* 

use "Data/Syrians pre and post crisis- educ.dta", clear

*Keeping Syrians over six with arrival years and individual weights
keep if group==2
keep if dec_age>=6 & dec_age<=40
keep if year_arrived!=.
keep if desc_weight_indiv!=.

*Keeping needed subset of variables
keep q3001 q2121 q2122 q2123 q2125 q2126 q2128 q2129 expan* dec_age sex brthyr indid ///
q3018 q3019 q3032 q3033 q3043 q3044 q3006_a year_arrived group desc_*

*Expanding 11x to potentially cover 2006-2016
expand 11

*Starting from 2006, counting to 2016
bysort indid: gen year=2005+_n

*Check
tabu year

*Cleaning years  
*End secondary as start of higher ed. if end secondary is missing
replace q3032=q3018 if q3018!=. & q3032==.
  
*In basic  
gen inschool_1=.
*Never went
replace inschool_1=0 if q3001==1
*Before started
replace inschool_1=0 if q2121>year & q2121<9998
*After finished
replace inschool_1=0 if q3043<=year & q3043<9998
replace inschool_1=0 if year>=q2128 & q2128!=9998 & q2128!=9999 
*During school (basic is 10 years) and done
replace inschool_1=1 if q2121<=year & q3043>year & q3043!=9998 & q3043!=.
replace inschool_1=1 if q2121<=year & q2128>year & q2128-q2121<11 & q2121!=9998 & q2128!=9998 & q2128!=9999 & q2128!=.
*Currently in school in basic
replace inschool_1=1 if q2121<=year & q3001==3 & q3006_a==1
*Interruption
replace inschool_1=0 if q2123==1 & year>=q2125 & year<q2126
 
*In secondary  
gen inschool_2=.
*Never went (at all, or only went to basic)
replace inschool_2=0 if q3001==1
replace inschool_2=0 if q3006_a==1
*Before started school or while in basic
replace inschool_2=0 if q2121>year & q2121<9998
replace inschool_2=0 if inschool_1==1
*After finished secondary
replace inschool_2=0 if q3032<=year & q3032<9998
*During school (secondary) and not in basic
replace inschool_2=1 if q2121<=year & q3032>year & q3032!=9998 & q3032!=. & inschool_1!=1
*Currently in school (in secondary, not in basic)
replace inschool_2=1 if q2121<=year & q3001==3 & q3006_a>=2 & q3006_a<=3 & inschool_1!=1
*Interruption
replace inschool_2=0 if q2123==1 & year>=q2125 & year<q2126

*Age appropriate level
gen age_year=year-2016+dec_age
tabu age_year

*Basic aged
gen of_age_1=0 if dec_age!=.
replace of_age_1=1 if age_year>=6 & age_year<16

*Secondary aged
gen of_age_2=0 if dec_age!=.
replace of_age_2=1 if age_year>=16 & age_year<18

*Check
tab1 inschool* , miss
tab1 of_age*, miss

tabu of_age_1 inschool_1
tabu of_age_2 inschool_2

tabu age_year if of_age_1==0 & inschool_1==1
tabu age_year if of_age_2==0 & inschool_2==1

bysort sex: tabu year inschool_1 if of_age_1==1
bysort sex: tabu year inschool_2 if of_age_2==1
*N small but okay for denominator

bysort sex: tabu year inschool_1 if of_age_1==1 [aw=desc_weight_indiv], row nofreq
bysort sex: tabu year inschool_2 if of_age_2==1 [aw=desc_weight_indiv], row nofreq

**********
*Figure 2: NERs By arrival
**********

*NERs exclude not of age
replace inschool_1=0 if of_age_1==0
replace inschool_2=0 if of_age_2==0
  

*For 2006 on
keep if year>=2006

gen year_from_arrival=year-year_arrived
drop year
rename year_from_arrival year

tabu year sex if of_age_1==1
tabu year sex if of_age_2==1


*Keep five years before and two after arrival
keep if year>=-5 & year<=2

*Collapse
collapse (sum) inschool_1 (sum) of_age_1 (sum) inschool_2 (sum) of_age_2 [pw=desc_weight_indiv], by(sex year)
 
*Create NERs 
gen ner_1=inschool_1/of_age_1*100
gen ner_2=inschool_2/of_age_2*100 

graph twoway lowess ner_1 year if sex==2, lpatt(shortdash) lcolor(gs1) lwidth(thick) bw(2) || ///
lowess ner_2 year if sex==2, lpatt(longdash) lcolor(gs1) lwidth(thick) bw(2) ///
|| lowess ner_1 year if sex==1, lpatt(shortdash) lcolor(gs8) lwidth(thick) bw(2) || ///
|| lowess ner_2 year if sex==1, lpatt(longdash) lcolor(gs8) lwidth(thick) bw(2) ///
||, plotregion(margin(none)) ///
       ylabel(0 (20) 100, gmin labs(medium) angle(horizontal)) ytitle("Net enrollment ratio (percentage)", size(4))  ///
       xlabel(-5 (1) 2, labs(medium) angle(horizontal)) xtitle("Year from arrival", size(4))  ///
       legend( rows(2) order(1 "Female basic" 2 "Female secondary" ///
		3 "Male basic" 4 "Male secondary")  ///
       note("")) xsize(5) ysize(3) graphregion(color(white)) xline(0)

graph save "Graphs and Tables/NER educ enroll by year_from_arrival.gph", replace
graph export "Graphs and Tables/NER educ enroll by year_from_arrival.png", replace width(800) 
  
    
		
*********************************
*Survival analysis
*********************************

use "Data/Syrians pre and post crisis- educ.dta", clear

*Need to have years of school
drop if yrschl==. 

*Keep Syrians in Jordan
keep if group==2

*ages 6-24 in December
keep if dec_age>=6 & dec_age<=24

*generate birth cohort
gen bcohort=.
replace bcohort=1 if brthyr>=1992 & brthyr<=1999
replace bcohort=2 if brthyr>=2000 & brthyr<=2004
replace bcohort=3 if brthyr>=2005 & brthyr<=2007
replace bcohort=4 if brthyr>=2008 & brthyr<=2011

label define bcohort 1 "1992-1999" 2 "2000-2004" 3 "2005-2007" 4 "2008-2011"
label values bcohort bcohort

*N check 
stset yrschl if dec_age>=6 & dec_age<=24, failure(dropout==1)
sts list
 
*Survival settings 
stset yrschl if dec_age>=6 & dec_age<=24 [pw=desc_weight_indiv], failure(dropout==1)

*********************************
*Figure 3: Exit by grade with cohorts
*********************************

sts graph, by(bcohort) ///
plot4opts(lpattern(l) lcolor(gs1) lwidth(medium))  ///
plot3opts(lpattern(longdash) lcolor(gs5) lwidth(medium)) ///
plot2opts(lpattern(dash) lcolor(gs9) lwidth(medium)) ///
plot1opts(lpattern(shortdash) lcolor(gs11) lwidth(medium)) ///
legend(title("On time start year", size(4)) ///
label(1 "1998-2005") label(2 "2006-2010") label(3 "2011-2013") label(4 "2014-2016")) plotregion(margin(none)) ///
xtitle("Grade") ytitle("Proportion in school") title("") ///
xlabel(0 (2) 12, gmin labs(medium) angle(horizontal)) ///
ylabel(0 (.2) 1.0, gmin labs(medium) angle(horizontal)) ///
tmax(12)

stsum, by(bcohort)
return list

sts list , by(bcohort)
 
graph save "Graphs and Tables/exit by cohort.gph", replace
graph export "Graphs and Tables/exit by cohort.png", width(800) replace 

*By sex -- footnote

bysort sex: table yrschl student bcohort 
 
sts graph if sex==1, by(bcohort) ///
plot4opts(lpattern(l) lcolor(gs1) lwidth(medium))  ///
plot3opts(lpattern(longdash) lcolor(gs5) lwidth(medium)) ///
plot2opts(lpattern(dash) lcolor(gs9) lwidth(medium)) ///
plot1opts(lpattern(shortdash) lcolor(gs11) lwidth(medium)) ///
legend(title("On time start year", size(4)) ///
label(1 "1998-2005") label(2 "2006-2010") label(3 "2011-2013") label(4 "2014-2016")) plotregion(margin(none)) ///
xtitle("Grade") ytitle("Proportion in school") title("") ///
xlabel(0 (2) 12, gmin labs(medium) angle(horizontal)) ///
ylabel(0 (.2) 1.0, gmin labs(medium) angle(horizontal)) ///
tmax(12)

graph save "Graphs and Tables/exit by cohort M.gph", replace
graph export "Graphs and Tables/exit by cohort M.png", width(800) replace 
 

sts graph if sex==2, by(bcohort) ///
plot4opts(lpattern(l) lcolor(gs1) lwidth(medium))  ///
plot3opts(lpattern(longdash) lcolor(gs5) lwidth(medium)) ///
plot2opts(lpattern(dash) lcolor(gs9) lwidth(medium)) ///
plot1opts(lpattern(shortdash) lcolor(gs11) lwidth(medium)) ///
legend(title("On time start year", size(4)) ///
label(1 "1998-2005") label(2 "2006-2010") label(3 "2011-2013") label(4 "2014-2016")) plotregion(margin(none)) ///
xtitle("Grade") ytitle("Proportion in school") title("") ///
xlabel(0 (2) 12, gmin labs(medium) angle(horizontal)) ///
ylabel(0 (.2) 1.0, gmin labs(medium) angle(horizontal)) ///
tmax(12)

graph save "Graphs and Tables/exit by cohort F.gph", replace
graph export "Graphs and Tables/exit by cohort F.png", width(800) replace 
 
*By sex ever entered -- footnote
 
sts graph if sex==1 & yrschl>=1, by(bcohort) ///
plot4opts(lpattern(l) lcolor(gs1) lwidth(medium))  ///
plot3opts(lpattern(longdash) lcolor(gs5) lwidth(medium)) ///
plot2opts(lpattern(dash) lcolor(gs9) lwidth(medium)) ///
plot1opts(lpattern(shortdash) lcolor(gs11) lwidth(medium)) ///
legend(title("On time start year", size(4)) ///
label(1 "1998-2005") label(2 "2006-2010") label(3 "2011-2013") label(4 "2014-2016")) plotregion(margin(none)) ///
xtitle("Grade") ytitle("Proportion in school") title("") ///
xlabel(0 (2) 12, gmin labs(medium) angle(horizontal)) ///
ylabel(0 (.2) 1.0, gmin labs(medium) angle(horizontal)) ///
tmax(12) 

sts graph if sex==2 & yrschl>=1, by(bcohort) ///
plot4opts(lpattern(l) lcolor(gs1) lwidth(medium))  ///
plot3opts(lpattern(longdash) lcolor(gs5) lwidth(medium)) ///
plot2opts(lpattern(dash) lcolor(gs9) lwidth(medium)) ///
plot1opts(lpattern(shortdash) lcolor(gs11) lwidth(medium)) ///
legend(title("On time start year", size(4)) ///
label(1 "1998-2005") label(2 "2006-2010") label(3 "2011-2013") label(4 "2014-2016")) plotregion(margin(none)) ///
xtitle("Grade") ytitle("Proportion in school") title("") ///
xlabel(0 (2) 12, gmin labs(medium) angle(horizontal)) ///
ylabel(0 (.2) 1.0, gmin labs(medium) angle(horizontal)) ///
tmax(12)
 
*********************************
*Stats: Interruption
********************************* 
 
use "Data/Syrians pre and post crisis- educ.dta", clear

*Started between 2005-2010 and exited 2011 or later
keep if q2121>=2005 & q2121<=2010 & q3001!=1 & q2128>=2011

*Keep 6-24 in December
keep if dec_age>=6 & dec_age<=24

*Syrians in Jordan and Jordanians
keep if group==1 | group==2

*N check
tabu group interrupt

*Interruptions
tabu group interrupt [aw=desc_weight_indiv], row nofreq
