*********************************************
* Ford Education Paper
* Caroline Krafft and Caitlyn Keo
* Survival analysis models
* v12
* Updated 2020.08.01
*********************************************

*************************************************************
***Sub-sample preparation
*************************************************************

*Use annualized data
use "Data/JLMPS annualized- educ.dta", clear

***Keeping 2006-2016
keep if year>=2006 & year<=2016

*Keeping only 0-12 grades
keep if grade>=0 & grade<=12

*December ages 6-24
keep if dec_age>=6 & dec_age<=24

*Syrians in Jordan
keep if group==2

keep if expan_indiv!=.

codebook indid
*N=1,111 Syrians

*Check when folks drop
tabu yrschl dropped 

*Creating grade segments
recode grade (0=0) (1/5=1) (6/8=2) (9/12=3), gen(grade_seg)
label def Lgrade_seg 0 "Entry" 1 "1-5" 2 "6-8" 3 "9-12"
la val grade_seg Lgrade_seg

*Creating periods of years
recode year (2006/2010=1) ///
(2011/2013=2) (2014/2016=3) (.=.) (9998=.), gen(tyr)

label var tyr "Years"
label define tyrlab 1 "2006-2010" 2 "2011-2013" 3 "2014-2016", modify
label values tyr tyrlab
tab year tyr



*************************************************************
***Discrete Time Proportional hazards models
*************************************************************

***************************
***Baseline hazards 
*****************************

*Model
cloglog dropped b0.grade, eform cluster(psu) 

*Testing grade segments
test 1.grade 2.grade 3.grade 4.grade 5.grade 
test 1.grade=2.grade=3.grade=4.grade=5.grade

test 6.grade 7.grade 8.grade 
test 6.grade=7.grade=8.grade

test 9.grade 10.grade 11.grade 12.grade
test 9.grade=10.grade=11.grade=12.grade

*******************************************
***Time trends--single year w/controls
*******************************************

*Check covariates
bysort group: sum sex motheredcat fatheredcat older_* younger_* nsibs

*Model
cloglog dropped b0.grade_seg##i.sex b2010.year ///
i.motheredcat i.fatheredcat ///
i.older_brothers i.older_sisters i.younger_brothers i.younger_sisters c.nsibs ///
i.sex#i.older_brothers i.sex#i.older_sisters i.sex#i.younger_brothers i.sex#i.younger_sisters i.sex#c.nsibs ///
,  eform cluster(psu) 

estimates store est1_Syr

*Test for joint sig., equivalence in periods
test 2006.year 2007.year 2008.year 2009.year 
test 2006.year=2007.year=2008.year=2009.year

test 2011.year 2012.year 2013.year 
test 2011.year=2012.year=2013.year

test 2014.year 2015.year 2016.year
test 2014.year=2015.year=2016.year


*************************************
***Time trends--grouped
*************************************

*Model
cloglog dropped b0.grade_seg##i.sex b1.tyr ///
i.motheredcat i.fatheredcat ///
i.older_brothers i.older_sisters i.younger_brothers i.younger_sisters c.nsibs ///
i.sex#i.older_brothers i.sex#i.older_sisters i.sex#i.younger_brothers i.sex#i.younger_sisters i.sex#c.nsibs ///
,  eform cluster(psu) 

estimates store est2_Syr

*Test for equivalence
test 2.tyr=3.tyr

**************************************
***Time trends w/grade int. 
**************************************

*Model
cloglog dropped b0.grade_seg##b1.tyr b0.grade_seg##i.sex ///
i.motheredcat i.fatheredcat ///
i.older_brothers i.older_sisters i.younger_brothers i.younger_sisters c.nsibs ///
i.sex#i.older_brothers i.sex#i.older_sisters i.sex#i.younger_brothers i.sex#i.younger_sisters i.sex#c.nsibs ///
,  eform cluster(psu) 

estimates store est3_Syr

*Margins
margins, over(grade_seg tyr) predict(pr)

********************
*Figure 4: Graph of margins
********************

mplotoffset, plotregion(margin(sides)) ///
xtitle("Grades", size(4)) ytitle("Hazard", size(4)) ///
plot1opts(lcolor(gs13) lpatt("l") mcolor(gs13))  ///
plot2opts(lcolor(gs7) lpatt(dash) mcolor(gs7))  ///
plot3opts(lcolor(gs1) lpatt("l") mcolor(gs1))  ///
ci1opts(lcolor(gs13) lpatt("l") msize(4))  ///
ci2opts(lcolor(gs7) lpatt(dash) msize(4))  ///
ci3opts(lcolor(gs1) lpatt("l") msize(4))  ///
title("") ///
ylabel(0(.1).5, labs(4)) ytick(0(.1).5) xlabel(, labs(3)) xtick() ///
legend(subtitle("Years") rows(1) col(5) size(3) symxsize(6.5)) ///
offset(0.05)

graph save "Graphs and Tables/yearint_coef_by3.gph", replace
graph export "Graphs and Tables/yearint_coef_by3.png", replace width(800)

*Tests
estimates restore est3_Syr

margins, over(grade_seg tyr) post coefleg

*Entry
test _b[0bn.grade_seg#1bn.tyr]=_b[0bn.grade_seg#2.tyr]
test _b[0bn.grade_seg#1bn.tyr]=_b[0bn.grade_seg#3.tyr]
test _b[0bn.grade_seg#2.tyr]=_b[0bn.grade_seg#3.tyr]

*Grade 1-5
test _b[1.grade_seg#1bn.tyr]=_b[1.grade_seg#2.tyr]
test _b[1.grade_seg#1bn.tyr]=_b[1.grade_seg#3.tyr]
test _b[1.grade_seg#2.tyr]=_b[1.grade_seg#3.tyr]

*Grade 6-8
test _b[2.grade_seg#1bn.tyr]=_b[2.grade_seg#2.tyr]
test _b[2.grade_seg#1bn.tyr]=_b[2.grade_seg#3.tyr]
test _b[2.grade_seg#2.tyr]=_b[2.grade_seg#3.tyr]

*Grade 9-12
test _b[3.grade_seg#1bn.tyr]=_b[3.grade_seg#2.tyr]
test _b[3.grade_seg#1bn.tyr]=_b[3.grade_seg#3.tyr]
test _b[3.grade_seg#2.tyr]=_b[3.grade_seg#3.tyr]


********************
*Table
********************


esttab est1_Syr est2_Syr est3_Syr using "Graphs and Tables/EduModels1.csv", cells(b(star fmt(%9.3f)) se(par))  ///     
 stats(N, fmt(%9.0g) labels("N obs.")) label  ///
 nobase noomit ///
  refcat(2.sex "Sex (male omit.)" ///
  1.grade_seg#2.sex "Grade and sex int." ///
  1.grade "Grade (Entry omit.)" 1.grade_seg "Grades (entry omit.)"  2006.year "Year (2010 omit.)" 2.tyr "Years (2006-2010 omit.)" ///
	1.grade_seg#2.tyr "Grades and years int." 2.motheredcat "Mother ed. (illit omit.)" 2.fatheredcat "Father ed. (illit. omit.)" ///
	2.in_loc "Location (Syria omit.)" ///
	1.grade_seg#2.in_loc "Grades and location int." ///
	1.older_brothers "Siblings main effects" 2.sex#1.older_brothers "Sibs. and sex int." ///
	, nolabel) ///
	legend  mlabel("Spec. 1" ///
	"Spec. 2"  ///
	"Spec 3."  ///
	, ) order(1.grade_seg 2.grade_seg 3.grade_seg *year* 2.tyr 3.tyr *grade_seg*tyr ///
	) ///
	eform replace
	
	

*************************************************************
***Check: Switching to location
*************************************************************

*Model
cloglog dropped b0.in_jordan b0.grade_seg##i.sex ///
i.motheredcat i.fatheredcat ///
i.older_brothers i.older_sisters i.younger_brothers i.younger_sisters c.nsibs ///
i.sex#i.older_brothers i.sex#i.older_sisters i.sex#i.younger_brothers i.sex#i.younger_sisters i.sex#c.nsibs ///
,  eform cluster(psu) 

*Model w/int. 
cloglog dropped b0.grade_seg##b0.in_jordan b0.grade_seg##i.sex ///
i.motheredcat i.fatheredcat ///
i.older_brothers i.older_sisters i.younger_brothers i.younger_sisters c.nsibs ///
i.sex#i.older_brothers i.sex#i.older_sisters i.sex#i.younger_brothers i.sex#i.younger_sisters i.sex#c.nsibs ///
,  eform cluster(psu) 

*estimates store est4_Syr	

	
**************************************
***Check: Time trends w/grade int. AND SEX
**************************************

*Model
cloglog dropped b0.grade_seg##b1.tyr##i.sex ///
i.motheredcat i.fatheredcat ///
i.older_brothers i.older_sisters i.younger_brothers i.younger_sisters c.nsibs ///
i.sex#i.older_brothers i.sex#i.older_sisters i.sex#i.younger_brothers i.sex#i.younger_sisters i.sex#c.nsibs ///
,  eform cluster(psu) 

*Test joint sig triple int. 
test 1.grade_seg#2.tyr#2.sex 2.grade_seg#2.tyr#2.sex 3.grade_seg#2.tyr#2.sex ///
1.grade_seg#3.tyr#2.sex 2.grade_seg#3.tyr#2.sex 3.grade_seg#3.tyr#2.sex ///
2.tyr#2.sex 3.tyr#2.sex

*Model
cloglog dropped b0.grade_seg##b1.tyr ///
i.motheredcat i.fatheredcat ///
i.older_brothers i.older_sisters i.younger_brothers i.younger_sisters c.nsibs ///
if sex==1,  eform cluster(psu) 


*Margins
margins, over(grade_seg tyr) predict(pr)

********************
*Graph of margins
********************

mplotoffset, plotregion(margin(sides)) ///
xtitle("Grades", size(4)) ytitle("Hazard", size(4)) ///
plot1opts(lcolor(gs13) lpatt("l") mcolor(gs13))  ///
plot2opts(lcolor(gs7) lpatt(dash) mcolor(gs7))  ///
plot3opts(lcolor(gs1) lpatt("l") mcolor(gs1))  ///
ci1opts(lcolor(gs13) lpatt("l") msize(4))  ///
ci2opts(lcolor(gs7) lpatt(dash) msize(4))  ///
ci3opts(lcolor(gs1) lpatt("l") msize(4))  ///
title("") ///
ylabel(0(.1).5, labs(4)) ytick(0(.1).5) xlabel(, labs(3)) xtick() ///
legend(subtitle("Years") rows(1) col(5) size(3) symxsize(6.5)) ///
offset(0.05)

graph save "Graphs and Tables/yearint_coef_by3 M.gph", replace
graph export "Graphs and Tables/yearint_coef_by3 M.png", replace width(800)


*Model
cloglog dropped b0.grade_seg##b1.tyr ///
i.motheredcat i.fatheredcat ///
i.older_brothers i.older_sisters i.younger_brothers i.younger_sisters c.nsibs ///
if sex==2,  eform cluster(psu) 


*Margins
margins, over(grade_seg tyr) predict(pr)

********************
*Graph of margins
********************

mplotoffset, plotregion(margin(sides)) ///
xtitle("Grades", size(4)) ytitle("Hazard", size(4)) ///
plot1opts(lcolor(gs13) lpatt("l") mcolor(gs13))  ///
plot2opts(lcolor(gs7) lpatt(dash) mcolor(gs7))  ///
plot3opts(lcolor(gs1) lpatt("l") mcolor(gs1))  ///
ci1opts(lcolor(gs13) lpatt("l") msize(4))  ///
ci2opts(lcolor(gs7) lpatt(dash) msize(4))  ///
ci3opts(lcolor(gs1) lpatt("l") msize(4))  ///
title("") ///
ylabel(0(.1).5, labs(4)) ytick(0(.1).5) xlabel(, labs(3)) xtick() ///
legend(subtitle("Years") rows(1) col(5) size(3) symxsize(6.5)) ///
offset(0.05)

graph save "Graphs and Tables/yearint_coef_by3 F.gph", replace
graph export "Graphs and Tables/yearint_coef_by3 F.png", replace width(800)

		
